@@ -1,11 +1,24 @@
+from pathlib import Path
+
 import sass
 
 from gilbert import Site
 from gilbert.content import Content, Renderable
+from gilbert.types import LoaderResult
 from gilbert.utils import oneshot
 
 
 class SCSS(Renderable, Content):
+    """
+    Content type that renders its content as SCSS
+
+    Additional options can be configured globally in ``config.yml``:
+
+    content_type:SCSS:
+
+    or using the ``scss_options`` attribute.
+    """
+
     output_extension: str = "css"
     scss_options: dict = {}
 
@@ -18,7 +31,7 @@ class SCSS(Renderable, Content):
         return sass.compile(string=self.data, **options)
 
 
-def load_scss(path):
+def load_scss(path: Path) -> LoaderResult:
     data = path.read_text(encoding="utf-8")
 
     return data, {"content_type": "SCSS"}
