@@ -1,19 +1,21 @@
 from operator import attrgetter
+from typing import List
 
+from gilbert.collection import Collection
 from gilbert.content import Content
 from gilbert.utils import oneshot
 
 
 class Selection(Content):
     """
-    A content type to provide sorted selections of pages / content.
+    A Content type to provide sorted selections of pages / content.
     """
 
     filter_by: dict = {}
     sort_by: str = "name"
     limit: int = 0
 
-    def select_objects(self, source):
+    def select_objects(self, source: Collection) -> List[Content]:
         sort_by = self.sort_by
         reverse = sort_by.startswith("-")
         if reverse:
@@ -26,8 +28,14 @@ class Selection(Content):
 
     @oneshot
     def pages(self):
+        """
+        Apply filtering and sorting to the Site's pages Collection, and return matching objects.
+        """
         return self.select_objects(self.site.pages)
 
     @oneshot
     def content(self):
+        """
+        Apply filtering and sorting to the Site's content Collection, and return matching objects.
+        """
         return self.select_objects(self.site.content)
