@@ -1,6 +1,10 @@
+from functools import update_wrapper
+
+
 class oneshot:
     def __init__(self, func):
         self.func = func
+        update_wrapper(self, func)
 
     def __set_name__(self, owner, name):
         self.name = name
